######
apeye
######

.. start short_desc

**Handy tools for working with URls and APIs.**

.. end short_desc


.. start shields

.. list-table::
	:stub-columns: 1
	:widths: 10 90

	* - Docs
	  - |docs| |docs_check|
	* - Tests
	  - |travis| |actions_windows| |actions_macos| |coveralls| |codefactor|
	* - PyPI
	  - |pypi-version| |supported-versions| |supported-implementations| |wheel|
	* - Activity
	  - |commits-latest| |commits-since| |maintained|
	* - Other
	  - |license| |language| |requires| |pre_commit|

.. |docs| image:: https://img.shields.io/readthedocs/apeye/latest?logo=read-the-docs
	:target: https://apeye.readthedocs.io/en/latest/?badge=latest
	:alt: Documentation Status

.. |docs_check| image:: https://github.com/domdfcoding/apeye/workflows/Docs%20Check/badge.svg
	:target: https://github.com/domdfcoding/apeye/actions?query=workflow%3A%22Docs+Check%22
	:alt: Docs Check Status

.. |travis| image:: https://img.shields.io/travis/com/domdfcoding/apeye/master?logo=travis
	:target: https://travis-ci.com/domdfcoding/apeye
	:alt: Travis Build Status

.. |actions_windows| image:: https://github.com/domdfcoding/apeye/workflows/Windows%20Tests/badge.svg
	:target: https://github.com/domdfcoding/apeye/actions?query=workflow%3A%22Windows+Tests%22
	:alt: Windows Tests Status

.. |actions_macos| image:: https://github.com/domdfcoding/apeye/workflows/macOS%20Tests/badge.svg
	:target: https://github.com/domdfcoding/apeye/actions?query=workflow%3A%22macOS+Tests%22
	:alt: macOS Tests Status

.. |requires| image:: https://requires.io/github/domdfcoding/apeye/requirements.svg?branch=master
	:target: https://requires.io/github/domdfcoding/apeye/requirements/?branch=master
	:alt: Requirements Status

.. |coveralls| image:: https://img.shields.io/coveralls/github/domdfcoding/apeye/master?logo=coveralls
	:target: https://coveralls.io/github/domdfcoding/apeye?branch=master
	:alt: Coverage

.. |codefactor| image:: https://img.shields.io/codefactor/grade/github/domdfcoding/apeye?logo=codefactor
	:target: https://www.codefactor.io/repository/github/domdfcoding/apeye
	:alt: CodeFactor Grade

.. |pypi-version| image:: https://img.shields.io/pypi/v/apeye
	:target: https://pypi.org/project/apeye/
	:alt: PyPI - Package Version

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/apeye?logo=python&logoColor=white
	:target: https://pypi.org/project/apeye/
	:alt: PyPI - Supported Python Versions

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/apeye
	:target: https://pypi.org/project/apeye/
	:alt: PyPI - Supported Implementations

.. |wheel| image:: https://img.shields.io/pypi/wheel/apeye
	:target: https://pypi.org/project/apeye/
	:alt: PyPI - Wheel

.. |license| image:: https://img.shields.io/github/license/domdfcoding/apeye
	:target: https://github.com/domdfcoding/apeye/blob/master/LICENSE
	:alt: License

.. |language| image:: https://img.shields.io/github/languages/top/domdfcoding/apeye
	:alt: GitHub top language

.. |commits-since| image:: https://img.shields.io/github/commits-since/domdfcoding/apeye/v0.0.3
	:target: https://github.com/domdfcoding/apeye/pulse
	:alt: GitHub commits since tagged version

.. |commits-latest| image:: https://img.shields.io/github/last-commit/domdfcoding/apeye
	:target: https://github.com/domdfcoding/apeye/commit/master
	:alt: GitHub last commit

.. |maintained| image:: https://img.shields.io/maintenance/yes/2020
	:alt: Maintenance

.. |pre_commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
	:target: https://github.com/pre-commit/pre-commit
	:alt: pre-commit

.. end shields

|

Installation
--------------

.. start installation

``apeye`` can be installed from PyPI.

To install with ``pip``:

.. code-block:: bash

	$ python -m pip install apeye

.. end installation
